@@ -369,13 +369,24 @@ load_font(struct font *fontp, Boolean use_t1lib)
 
     fontp->file = NULL;
 
-    /* update for font loading popup */
-    if (--globals.events.ctr == 0) {
-	read_events(EV_GE_IDLE);
-    }
-    /* same trick as in statusline.c */
-    force_statusline_update();
-    XSync(DISP, False);
+    /* BUG ALERT: This used to be:
+     *
+     * if (--globals.ev.ctr == 0) {
+     *     read_events(EV_GE_IDLE);
+     * }
+     * force_statusline_update();
+     * XSync(DISP, False);
+     *
+     * The idea was to update the `loading fonts ...' popup. However,
+     * calling read_events() here may call dvi_file_changed() if the
+     * user clicks on the window, which calls file_exists_p(), and
+     * that changes m_dvi_fp while it's still being used to read the
+     * postamble (where load_font() is called from), which will cause
+     * xdvi to crash! (bug #968127).
+     *
+     * Sadly, without this update, the `loading fonts' popup doesn't
+     * appear before the main window comes up ...
+     */
 
 #ifdef T1LIB
     fontp->file = font_open(fontp->fontname, &font_found,
@@ -387,14 +398,6 @@ load_font(struct font *fontp, Boolean use_t1lib)
 			    &fontp->filename);
 #endif /* T1LIB */
 
-    /* update again ... */
-    if (--globals.events.ctr == 0) {
-	read_events(EV_GE_IDLE);
-    }
-    /* same trick as in statusline.c */
-    force_statusline_update();
-    XSync(DISP, False);
-
 #ifdef T1LIB
     if (fontp->t1id >= 0 && use_t1lib) {
 	/* It's a type1 font */
@@ -420,7 +423,7 @@ load_font(struct font *fontp, Boolean use_t1lib)
 #endif /* T1LIB */
     /* when not using T1lib, fontp->file == NULL means total failure */
     if (fontp->file == NULL) {
-	if (globals.events.flags & EV_GE_NEWDOC)
+	if (globals.ev.flags & EV_GE_NEWDOC)
 	    return False;
 	fontp->flags |= FONT_LOADED;	/* as loaded as it'll get */
 	XDVI_ERROR((stderr, "Can't find font %s.%dpk", fontp->fontname, dpi));
@@ -642,7 +645,7 @@ define_font(Boolean load_font_now,	/* only scanning, or also loading the font? *
 	    fontp->scale = scale;
 	    if (vfparent == NULL)
 		if (!load_font(fontp, resource.t1lib)) {
-		    if (globals.events.flags & EV_GE_NEWDOC) {	/* if aborting */
+		    if (globals.ev.flags & EV_GE_NEWDOC) {	/* if aborting */
 			free(fontname);
 			free(fontp);
 			return NULL;
@@ -729,6 +732,8 @@ find_postamble(FILE *fp, dviErrFlagT *errflag)
     ubyte *p1;
     ubyte byte;
 
+    TRACE_FILES((stderr, "find_postamble on fp: %p", (void *)fp));
+    
     fseek(fp, 0L, SEEK_END);
     pos = ftell(fp) - TMPSIZ;
     if (pos < 0)
@@ -744,6 +749,7 @@ find_postamble(FILE *fp, dviErrFlagT *errflag)
 	    break;	/* found 4 TRAILER bytes */
 	if (p <= temp) {
 	    *errflag = DVI_CORRUPTED;
+	    TRACE_FILES((stderr, "find_postamble: returning FALSE"));
 	    return False;
 	}
     }
@@ -755,10 +761,12 @@ find_postamble(FILE *fp, dviErrFlagT *errflag)
     }
     if (byte != 2) {
 	*errflag = WRONG_DVI_VERSION;
+	TRACE_FILES((stderr, "find_postamble: returning FALSE"));
 	return False;
     }
     fseek(fp, pos - 4, SEEK_SET);
     fseek(fp, get_lbytes(fp, 4), SEEK_SET);
+    TRACE_FILES((stderr, "find_postamble: returning TRUE"));
     return True;
 }
 
@@ -820,9 +828,21 @@ read_postamble(FILE *fp, dviErrFlagT *errflag, Boolean load_fonts)
 {
     ubyte cmnd;
     Boolean font_not_found = False;
+    struct font	*fontp;
 
+    TRACE_FILES((stderr, "read_postamble: reading %p (%d)", (void *)fp, load_fonts));
+
+    /* clear existing font table */
+    bzero((char *)tn_table, (int)sizeof tn_table);
+    free_vf_chain(tn_head);
+    tn_head = NULL;
+    for (fontp = font_head; fontp != NULL; fontp = fontp->next)
+	fontp->flags &= ~FONT_IN_USE;
+
+    
     if (get_byte(fp) != POST) {
 	*errflag = POSTAMBLE_NO_POST;
+	TRACE_FILES((stderr, "read_postamble: returning FALSE"));
 	return False;
     }
     m_last_page_offset = get_bytes(fp, 4);
@@ -830,6 +850,7 @@ read_postamble(FILE *fp, dviErrFlagT *errflag, Boolean load_fonts)
 	|| denominator != get_bytes(fp, 4)
 	|| magnification != get_bytes(fp, 4)) {
 	*errflag = POSTAMBLE_NO_MATCH;
+	TRACE_FILES((stderr, "read_postamble: returning FALSE"));
 	return False;
     }
 
@@ -843,24 +864,32 @@ read_postamble(FILE *fp, dviErrFlagT *errflag, Boolean load_fonts)
     (void)get_bytes(fp, 2);	/* max stack size */
     total_pages = get_bytes(fp, 2);
 
+    /* read font definitions */
     while ((cmnd = get_byte(fp)) >= FNTDEF1 && cmnd <= FNTDEF4) {
-	struct font *f = define_font(load_fonts, fp, cmnd, (struct font *) NULL, tn_table,
+	struct font *f = define_font(load_fonts, fp, cmnd, (struct font *)NULL, tn_table,
 				     TNTABLELEN, &tn_head, &font_not_found);
-	if (load_fonts && f == NULL)
+	if (load_fonts && f == NULL) {
+	    TRACE_FILES((stderr, "read_postamble: returning FALSE"));
 	    return False;
-	else if (!load_fonts) /* return early */
+	}
+	else if (!load_fonts) { /* return early */
+	    TRACE_FILES((stderr, "read_postamble: returning TRUE"));
 	    return True;
+	}
     }
     if (cmnd != POSTPOST) {
 	*errflag = POSTAMBLE_NON_FNTDEF;
+	TRACE_FILES((stderr, "read_postamble: returning FALSE"));
 	return False;
     }
     if (font_not_found) {
 	*errflag = NOT_ALL_PIXEL_FILES_FOUND;
+	TRACE_FILES((stderr, "read_postamble: returning FALSE"));
 	return False;
     }
     free_unused_fonts();
 
+    TRACE_FILES((stderr, "read_postamble: returning TRUE"));
     return True;
 }
 
@@ -871,6 +900,9 @@ prepare_pages(dviErrFlagT *errflag)
     int i;
     long offset;
 
+    TRACE_FILES((stderr, "calling pageinfo_deallocate"));
+    pageinfo_deallocate();
+
     TRACE_FILES((stderr, "pageinfo_allocate for %d pages", total_pages + 1));
     pageinfo_allocate(total_pages + 1);
     pageinfo_set_page_width(total_pages, m_paper_unshrunk_w);
@@ -1013,28 +1045,17 @@ make_backup_fp(FILE *source_fp, FILE *target_fp)
     return target_fp;
 }
 
-/*
- *	internal_open_dvi does the real opening of the dvi file, and sets
- *	globals.dvi_file.time.  It returns True on success, and sets m_dvi_fp and globals.dvi_file.bak_fp.
- */
-
-Boolean
-internal_open_dvi(const char *path, dviErrFlagT *errflag)
+static Boolean
+file_exists_p(const char *path, dviErrFlagT *errflag)
 {
-    struct font	*fontp;
-/*     FILE *tmp_fp = NULL; */
-/*     static FILE *bak_fp = NULL; /\* re-use the temporary backup fp *\/ */
-/*      fprintf(stderr, "------------ opening: |%s|\n", path); */
-
-    TRACE_FILES((stderr, "internal_open_dvi for |%s|", path));
-    close_old_filep();
-
+    TRACE_FILES((stderr, "file_exists_p for |%s|", path));
     *errflag = UNKNOWN_ERROR;
     if ((m_dvi_fp = XFOPEN(path, OPEN_MODE)) == NULL) {
 /*  	fprintf(stderr, "after internal_open_dvi1: xfopen\n"); */
 	*errflag = FILE_DOESNT_EXIST;
 	return False;
     }
+    TRACE_FILES((stderr, "m_dvi_fp for |%s| = %p", path, (void *)m_dvi_fp));
 /*      fprintf(stderr, "after internal_open_dvi2: xfopen\n"); */
     
     /* shouldn't happen */
@@ -1058,27 +1079,95 @@ internal_open_dvi(const char *path, dviErrFlagT *errflag)
 	m_dvi_fp = NULL;
 	return False;
     }
+    return True;
+}
 
-    TRACE_FILES((stderr, "calling pageinfo_deallocate"));
-    pageinfo_deallocate();
+/*
+ *	internal_init_dvi is the main subroutine for reading the startup
+ *	information from the dvi file.
+ */
 
+static Boolean
+internal_init_dvi(dviErrFlagT *errflag, Boolean load_fonts)
+{
+    char *icon_name = NULL, *title_name = NULL;
+
+    have_src_specials = False;
+
+    TRACE_FILES((stderr, "internal_init_dvi, globals.dvi_file.bak_fp = %p", (void *)globals.dvi_file.bak_fp));
+    
+    if (!process_preamble(globals.dvi_file.bak_fp, errflag)
+	|| !find_postamble(globals.dvi_file.bak_fp, errflag)
+	|| !read_postamble(globals.dvi_file.bak_fp, errflag, load_fonts)
+	|| !prepare_pages(errflag))
+	return False;
+
+    if (current_page >= total_pages)
+	current_page = total_pages - 1;
+
+    globals.warn_spec_now = resource.warn_spec;
+    globals.src.fwd_box_page = -1;
+    search_reset_info();
+    
+    if (globals.pausing.num_save != NULL) {
+	free(globals.pausing.num_save);
+	globals.pausing.num_save = NULL;
+    }
+    if (resource.pause && total_pages > 0) {
+	globals.pausing.num_save = xmalloc(total_pages * sizeof *globals.pausing.num_save);
+	memset(globals.pausing.num_save, 0, total_pages * sizeof *globals.pausing.num_save);
+    }
+    
+    init_prescan();
+    /* this allocates icon_name and title_name */
+    get_icon_and_title(globals.dvi_name, &icon_name, &title_name);
+    set_icon_and_title(icon_name, title_name);
+    free(icon_name);
+    free(title_name);
+    icon_name = title_name = NULL;
+    
+#if defined(MOTIF) && HAVE_XPM
+    tb_check_navigation_sensitivity(current_page);
+#endif
+    refresh_pagelist(total_pages, current_page);
+
+    return True;
+}
+
+/*
+ *	internal_open_dvi does the real opening of the dvi file, and sets
+ *	globals.dvi_file.time.  It returns True on success, and sets m_dvi_fp and globals.dvi_file.bak_fp.
+ */
+
+Boolean
+internal_open_dvi(const char *path, dviErrFlagT *errflag, Boolean load_fonts)
+{
+/*     FILE *tmp_fp = NULL; */
+/*     static FILE *bak_fp = NULL; /\* re-use the temporary backup fp *\/ */
+/*      fprintf(stderr, "------------ opening: |%s|\n", path); */
+
+    TRACE_FILES((stderr, "internal_open_dvi for |%s|", path));
+    close_old_filep();
+
+    if (!file_exists_p(path, errflag)) { /* this should set fstatbuf.st_mtime */
+	return False;
+    }
+
+    if (!resource.use_temp_fp || (globals.dvi_file.bak_fp = make_backup_fp(m_dvi_fp, globals.dvi_file.bak_fp)) == NULL) {
+	globals.dvi_file.bak_fp = m_dvi_fp;
+    }
+    globals.dvi_file.time = fstatbuf.st_mtime;
+    
+    if (!internal_init_dvi(errflag, load_fonts)) {
+	return False;
+    }
+    
 #if COLOR
     full_reset_colors();
 #endif /* COLOR */
     reset_papersize_special();
     
-    bzero((char *)tn_table, (int)sizeof tn_table);
-    free_vf_chain(tn_head);
-    tn_head = NULL;
-    for (fontp = font_head; fontp != NULL; fontp = fontp->next)
-	fontp->flags &= ~FONT_IN_USE;
-
     TRACE_FILES((stderr, "internal_open_dvi: SUCCESS!"));
-    
-    if (!resource.use_temp_fp || (globals.dvi_file.bak_fp = make_backup_fp(m_dvi_fp, globals.dvi_file.bak_fp)) == NULL) {
-	globals.dvi_file.bak_fp = m_dvi_fp;
-    }
-    globals.dvi_file.time = fstatbuf.st_mtime;
 
     return True;
 }
@@ -1191,7 +1280,7 @@ find_dvi_file(const char *filename, Boolean *tried_dvi_ext, Boolean from_file_hi
 	new_filename = xstrcat(new_filename, ".dvi");
 	*tried_dvi_ext = True;
 	
-	if (internal_open_dvi(new_filename, &errflag)) { /* file exists */
+	if (file_exists_p(new_filename, &errflag)) { /* file exists */
 	    char *expanded_filename = expand_filename(new_filename, USE_CWD_PATH);
 	    free(new_filename);
 	    return expanded_filename;
@@ -1202,7 +1291,7 @@ find_dvi_file(const char *filename, Boolean *tried_dvi_ext, Boolean from_file_hi
     }
 
     /* try verbatim filename (might be strange things like `foo.wdvi') */
-    if (internal_open_dvi(filename, &errflag)) {
+    if (file_exists_p(filename, &errflag)) {
 	char *expanded_filename = expand_filename(filename, USE_CWD_PATH);
 	return expanded_filename;
     }
@@ -1235,9 +1324,9 @@ find_dvi_file(const char *filename, Boolean *tried_dvi_ext, Boolean from_file_hi
 
 /*
  * A wrapper for open_dvi_file that can also deal with remote files/URLs, and other
- * file types.
+ * file types. Returns the (newly malloc'ed) new dvi file name if it succeeds, NULL else.
  */
-Boolean
+char *
 open_dvi_file_wrapper(const char *filename,
 		      Boolean from_command_line,
 		      Boolean open_new_instance,
@@ -1245,6 +1334,7 @@ open_dvi_file_wrapper(const char *filename,
 		      Boolean from_file_history)
 {
     char *real_filename = NULL;
+    char *new_dvi_name = NULL;
     char canonical_path[MAXPATHLEN + 1];
     
     if (from_command_line) {
@@ -1260,12 +1350,12 @@ open_dvi_file_wrapper(const char *filename,
 	if (real_filename == NULL)
 	    return False;
 	
-	TRACE_HTEX((stderr, "filename |%s| %p from commandline;\ndvi_name: |%s|%p,\nfilename: |%s|%p",
-		    real_filename, real_filename, globals.dvi_name, (void *)globals.dvi_name, filename, (void *)filename));
-	free(globals.dvi_name);
-	globals.dvi_name = xstrdup(REALPATH(real_filename, canonical_path));
-	TRACE_FILES((stderr, "dvi name: |%s| %p", globals.dvi_name, globals.dvi_name));
-	return True;
+	TRACE_HTEX((stderr, "filename |%s| %p from commandline;\ndvi_name: |%s|,\nfilename: |%s|%p",
+		    real_filename, real_filename, globals.dvi_name, filename, (void *)filename));
+	new_dvi_name = xstrdup(REALPATH(real_filename, canonical_path));
+	free(real_filename);
+	TRACE_FILES((stderr, "new_dvi_name: |%s|", new_dvi_name));
+	return new_dvi_name;
     }
     else {
 	/*
@@ -1283,18 +1373,12 @@ open_dvi_file_wrapper(const char *filename,
 		if (open_dvi_file(expanded_filename, open_new_instance)) {
 		    TRACE_FILES((stderr, "success: %p |%s|", expanded_filename, expanded_filename));
 		    if (!open_new_instance) {
-			free(globals.dvi_name);
-			globals.dvi_name = expand_filename_append_dvi(expanded_filename, USE_DVI_PATH, True);
-			TRACE_FILES((stderr, "globals.dvi_name: %p |%s|", globals.dvi_name, globals.dvi_name));
-			
-			free(globals.dvi_file.dirname);
-			globals.dvi_file.dirname = get_dir_component(globals.dvi_name);
-			ASSERT(globals.dvi_file.dirname != NULL, "dvi_name contains no directory component");
-			globals.dvi_file.dirlen = strlen(globals.dvi_file.dirname);
+			new_dvi_name = expand_filename_append_dvi(expanded_filename, USE_DVI_PATH, True);
+			TRACE_FILES((stderr, "new_dvi_name: %p |%s|", (void*)new_dvi_name, new_dvi_name));
 		    }
 		}
 		free(expanded_filename);
-		return True;
+		return new_dvi_name;
 	    }
 	    else {
 		/*
@@ -1303,13 +1387,13 @@ open_dvi_file_wrapper(const char *filename,
 		*/
 		TRACE_HTEX((stderr, "%s is NOT a DVI file", filename_no_prefix));
 		launch_program(filename);
-		return False;
+		return NULL;
 	    }
 	}
 	else {
 	    /* not a local file, retrieve it with the browser: */
 	    launch_browser(filename);
-	    return False;
+	    return NULL;
 	}
     }
 }
@@ -1331,8 +1415,8 @@ open_dvi_file(const char *filename, Boolean open_new_instance)
     else {
 	dviErrFlagT errflag = NO_ERROR;
 	TRACE_HTEX((stderr, "internal_open_dvi: |%s|", filename));
-	if (!internal_open_dvi(filename, &errflag)
-	    || !internal_init_dvi(&errflag, True)) {
+	if (!internal_open_dvi(filename, &errflag, True)) {
+/*  	    || !internal_init_dvi(&errflag, True)) { */
 	    report_open_error("Cannot open DVI file", filename, errflag);
 	    retval = False;
 	}
@@ -1368,57 +1452,6 @@ form_dvi_property(void)
     strcpy(dvi_property, globals.dvi_name);
 }
 
-/*
- *	internal_init_dvi is the main subroutine for reading the startup
- *	information from the dvi file.
- */
-
-Boolean
-internal_init_dvi(dviErrFlagT *errflag, Boolean load_fonts)
-{
-    char *icon_name = NULL, *title_name = NULL;
-
-    have_src_specials = False;
-
-    TRACE_FILES((stderr, "internal_init_dvi, globals.dvi_file.bak_fp = %p", (void *)globals.dvi_file.bak_fp));
-    
-    if (!process_preamble(globals.dvi_file.bak_fp, errflag)
-	|| !find_postamble(globals.dvi_file.bak_fp, errflag)
-	|| !read_postamble(globals.dvi_file.bak_fp, errflag, load_fonts)
-	|| !prepare_pages(errflag))
-	return False;
-
-    if (current_page >= total_pages)
-	current_page = total_pages - 1;
-
-    globals.warn_spec_now = resource.warn_spec;
-    globals.src.fwd_box_page = -1;
-    search_reset_info();
-    
-    if (globals.pausing.num_save != NULL) {
-	free(globals.pausing.num_save);
-	globals.pausing.num_save = NULL;
-    }
-    if (resource.pause && total_pages > 0) {
-	globals.pausing.num_save = xmalloc(total_pages * sizeof *globals.pausing.num_save);
-	memset(globals.pausing.num_save, 0, total_pages * sizeof *globals.pausing.num_save);
-    }
-    
-    init_prescan();
-    /* this allocates icon_name and title_name */
-    get_icon_and_title(globals.dvi_name, &icon_name, &title_name);
-    set_icon_and_title(icon_name, title_name);
-    free(icon_name);
-    free(title_name);
-    icon_name = title_name = NULL;
-    
-#if defined(MOTIF) && HAVE_XPM
-    tb_check_navigation_sensitivity(current_page);
-#endif
-    refresh_pagelist(total_pages, current_page);
-
-    return True;
-}
 
 /* access for m_dvi_fp */
 void
@@ -1450,10 +1483,24 @@ dvi_file_changed(void)
 	if (stat(globals.dvi_name, &fstatbuf) == 0 && fstatbuf.st_mtime != globals.dvi_file.time) {
 	    TRACE_FILES((stderr, "file changed"));
 	    if (resource.use_temp_fp) {
+		dviErrFlagT errflag = NO_ERROR;
+
 		if (resource.watch_file == 0.0)
 		    statusline_print(STATUS_MEDIUM, "File changed ...");
 		TRACE_FILES((stderr, "returning FALSE"));
-		return False;
+
+		if (file_exists_p(globals.dvi_name, &errflag)
+		    && process_preamble(m_dvi_fp, &errflag)
+		    && find_postamble(m_dvi_fp, &errflag)
+		    && read_postamble(m_dvi_fp, &errflag, False)) {
+		    TRACE_FILES((stderr, "File OK, reloading ..."));
+		    
+		    globals.ev.flags |= EV_RELOAD;
+		    return True;
+		}
+		else {
+		    return False;
+		}
 	    }
 	    /* Bug alert: Don't set EV_RELOAD again here, else xdvi
 	       can go into a stretch of time where it again and again
@@ -1462,34 +1509,42 @@ dvi_file_changed(void)
 	    */
 	    /*
 	    else {
-		globals.events.flags |= EV_RELOAD;
+		globals.ev.flags |= EV_RELOAD;
 	    }
 	    */
+	    TRACE_FILES((stderr, "returning TRUE"));
 	    return True;
 	}
+	else {
+	    TRACE_FILES((stderr, "file not changed"));
+	}
     }
-    else if (fstat(fileno(m_dvi_fp), &fstatbuf) != 0 /* stat failed ... */
+    /* BUG ALERT: Don't use fstat(fileno(m_dvi_fp) here; if file hase
+       disappeared, this won't report an error! */
+    else if (stat(globals.dvi_name, &fstatbuf) != 0 /* stat failed ... */
 	     || fstatbuf.st_mtime != globals.dvi_file.time /* ... or different timestamp, reload: */) {
 	dviErrFlagT errflag = NO_ERROR;
 
 	TRACE_FILES((stderr, "Stat failed, or different timestamp ..."));
-
+	globals.dvi_file.time = 0; /* force reload next time also if stat failed */
+	
 	if (resource.use_temp_fp) { /* in this case, reload only if file has been written completely */
 	    if (resource.watch_file == 0.0) {
 		statusline_print(STATUS_MEDIUM, "File corrupted (click on window to reload) ...");
 		globals.cursor.flags |= CURSOR_CORRUPTED;
-		globals.events.flags |= EV_CURSOR;
+		globals.ev.flags |= EV_CURSOR;
 	    }
 	    else {
 		statusline_print(STATUS_MEDIUM, "File corrupted (will try to reload) ...");
 	    }
-	    fseek(m_dvi_fp, 0L, SEEK_SET);
-	    if (process_preamble(m_dvi_fp, &errflag)
+	    close_old_filep();
+	    if (file_exists_p(globals.dvi_name, &errflag)
+		&& process_preamble(m_dvi_fp, &errflag)
 		&& find_postamble(m_dvi_fp, &errflag)
 		&& read_postamble(m_dvi_fp, &errflag, False)) {
 		TRACE_FILES((stderr, "File OK, reloading ..."));
 		
-		globals.events.flags |= EV_RELOAD;
+		globals.ev.flags |= EV_RELOAD;
 		return True;
 	    }
 	    else {
@@ -1500,7 +1555,7 @@ dvi_file_changed(void)
 	}
 	else {
 	    TRACE_FILES((stderr, "Not using temp fp, reloading..."));
-	    globals.events.flags |= EV_RELOAD;
+	    globals.ev.flags |= EV_RELOAD;
 	    return True;
 	}
     }
@@ -1517,6 +1572,8 @@ load_dvi_file(Boolean load_fonts, dviErrFlagT *errflag)
     unsigned int old_page_w, old_page_h;
     static ino_t dvi_inode = 0;
 
+    TRACE_FILES((stderr, "load_dvi_file: going to read %p", (void *)m_dvi_fp));
+    
     if (resource.use_temp_fp && m_dvi_fp != NULL) {
 	/* in this case, reload only if file has been written completely */
 	*errflag = NO_ERROR;
@@ -1535,8 +1592,8 @@ load_dvi_file(Boolean load_fonts, dviErrFlagT *errflag)
     old_page_h = globals.page.h;
 
     *errflag = NO_ERROR;
-    if (!internal_open_dvi(globals.dvi_name, errflag)
-	|| !internal_init_dvi(errflag, load_fonts)) { /* failure */
+    if (!internal_open_dvi(globals.dvi_name, errflag, load_fonts)) {
+/*  	|| !internal_init_dvi(errflag, load_fonts)) { */
 	XClearWindow(DISP, mane.win);
 	XBell(DISP, 0);
 	statusline_print(STATUS_MEDIUM, "%s: %s%s", globals.dvi_name, get_dvi_error(*errflag),
@@ -1560,42 +1617,3 @@ load_dvi_file(Boolean load_fonts, dviErrFlagT *errflag)
 	return True;
     }
 }
-
-/*
- * Used with -watchfile: Reload the file, but only if it's a valid DVI file.
- */
-void
-check_watch_dvi_file(void)
-{
-    struct stat fstatbuf;
-    dviErrFlagT errflag;
-    FILE *new_file = NULL;
-
-    if (m_dvi_fp != NULL && fstat(fileno(m_dvi_fp), &fstatbuf) != 0) {
-	TRACE_EVENTS((stderr, "watching: stat failed."));
-    }
-    else if (fstatbuf.st_mtime != globals.dvi_file.time) {
-	TRACE_EVENTS((stderr, "watching: file has changed."));
-	globals.cursor.flags |= CURSOR_CORRUPTED;
-	globals.events.flags |= EV_CURSOR;
-	if ((new_file = XFOPEN(globals.dvi_name, OPEN_MODE)) != NULL) {
-	    TRACE_EVENTS((stderr, "watching: new file opened successfully."));
-	    if (process_preamble(new_file, &errflag)
-		&& find_postamble(new_file, &errflag)
-		&& read_postamble(new_file, &errflag, False)) {
-		TRACE_EVENTS((stderr, "watching: file is OK - reloading."));
-
-		close_old_filep();
-		globals.events.flags |= EV_NEWDOC;
-	    }
-	    else {
-		TRACE_EVENTS((stderr, "watching: file seems corrupted"));
-	    }
-	    fclose(new_file);
-	}
-	else {
-	    TRACE_EVENTS((stderr, "watching: couldn't open |%s|", globals.dvi_name));
-	}
-    }
-}
-
