@@ -371,7 +371,7 @@ scan_page_for_specials(FILE *fp, int page, Boolean save_stack,
 	if (read_events(EV_NOWAIT) & EV_GE_NEWPAGE)
 	    break;
 	page_bak = page;
-	if (!setjmp(globals.events.canit)) {
+	if (!setjmp(globals.ev.canit)) {
 	    fprintf(stderr, "current position: %lu; seeking to: %lu\n",
 		    (unsigned long)pos_save,
 		    (unsigned long)pageinfo_get_offset(page));
