@@ -383,6 +383,8 @@ initialize_items(struct topic_info *info)
 	"\n",
 #endif	
 	"     Opens a popup window to select another DVI file.\n",
+	"     With a prefix argument `n', the `n'th file from the file history\n",
+	"     is opened instead.\n",
 	"\n",
 	"Ctrl-p",
 #if MOTIF
