@@ -927,11 +927,9 @@ popup_message(Widget parent, popupMessageT type, const char *helptext, const cha
 {
     char *msg_buf = NULL;
     Widget w;
-    
-    va_list argp;
-    va_start(argp, format);
-    msg_buf = get_string_argp(format, argp);
-    va_end(argp);
+
+    XDVI_GET_STRING_ARGP(msg_buf, format);
+
     w = internal_popup_window(parent,
 			      SIZE_SMALL,
 			      type,
@@ -959,10 +957,8 @@ popup_message_sized(Widget parent,
     char *msg_buf = NULL;
     Widget w;
     
-    va_list argp;
-    va_start(argp, format);
-    msg_buf = get_string_argp(format, argp);
-    va_end(argp);
+    XDVI_GET_STRING_ARGP(msg_buf, format);
+
     w = internal_popup_window(parent,
 			      sizehint,
 			      type,
@@ -989,10 +985,8 @@ positioned_popup_message(Widget parent,
     char *msg_buf = NULL;
     Widget w;
     
-    va_list argp;
-    va_start(argp, format);
-    msg_buf = get_string_argp(format, argp);
-    va_end(argp);
+    XDVI_GET_STRING_ARGP(msg_buf, format);
+
     w = internal_popup_window(parent,
 			      SIZE_SMALL,
 			      type,
@@ -1025,10 +1019,8 @@ choice_dialog(Widget parent,
     char *msg_buf = NULL;
     Widget w;
     
-    va_list argp;
-    va_start(argp, format);
-    msg_buf = get_string_argp(format, argp);
-    va_end(argp);
+    XDVI_GET_STRING_ARGP(msg_buf, format);
+
     w = internal_popup_window(parent,
 			      SIZE_SMALL,
 			      type,
@@ -1059,10 +1051,8 @@ choice3_dialog(Widget parent,
     char *msg_buf = NULL;
     Widget w;
     
-    va_list argp;
-    va_start(argp, format);
-    msg_buf = get_string_argp(format, argp);
-    va_end(argp);
+    XDVI_GET_STRING_ARGP(msg_buf, format);
+
     w = internal_popup_window(parent,
 			      SIZE_SMALL,
 			      type,
@@ -1093,10 +1083,8 @@ choice_dialog_sized(Widget parent,
     char *msg_buf = NULL;
     Widget w;
     
-    va_list argp;
-    va_start(argp, format);
-    msg_buf = get_string_argp(format, argp);
-    va_end(argp);
+    XDVI_GET_STRING_ARGP(msg_buf, format);
+
     w = internal_popup_window(parent,
 			      sizehint,
 			      type,
@@ -1129,10 +1117,8 @@ positioned_choice_dialog(Widget parent,
     char *msg_buf = NULL;
     Widget w;
     
-    va_list argp;
-    va_start(argp, format);
-    msg_buf = get_string_argp(format, argp);
-    va_end(argp);
+    XDVI_GET_STRING_ARGP(msg_buf, format);
+
     w = internal_popup_window(parent,
 			      SIZE_SMALL,
 			      type,
