@@ -253,7 +253,7 @@ struct page_index_info {
     char **page_labels;  /* label strings */
 };
 
-struct page_index_info page_info;
+static struct page_index_info page_info;
 
 /* access functions used by dvi-draw.c and dvi-init.c */
 long
@@ -951,6 +951,9 @@ xm_toggle_label(Widget widget, int idx, Boolean update)
     /* TODO: use `update' to update all labels at once when toggling multiple */
     XmString str;
     char *mark_font, buf[128];
+
+    if (widget == NULL)
+	return;
     
     UNUSED(update);
 
@@ -1000,6 +1003,10 @@ xaw_create_pagelist_widgets(Dimension height, Dimension width, Position y, Widge
     viewport = XtVaCreateWidget("viewport",
 				viewportWidgetClass, parent,
 				XtNallowVert, True,
+#ifdef __GNUC__
+#warning FIXME: when loading new file with more digits in page numbers, viewport is not resized
+#endif
+				/* this is not related to the scroll bar: */
 				/* XtNforceBars, True, */
 				XtNx, resource.btn_side_spacing,
 				XtNy, y,
@@ -1053,7 +1060,8 @@ xaw_create_pagelist_widgets(Dimension height, Dimension width, Position y, Widge
 static void
 xaw_toggle_label(Widget w, int idx, Boolean update)
 {
-    UNUSED(w);
+    if (w == NULL)
+	return;
 
 /*     ensure_labelinfo_size(idx); */
     ASSERT(idx < (int)page_info.index_size, "");
