@@ -2215,7 +2215,7 @@ save_or_print_callback(struct save_or_print_info *info)
     if (globals.pageno_correct == 1)
 	sprintf(ofstring, "of %d physical pages", total_pages);
     else
-	sprintf(ofstring, "of %d to %d physical pages", globals.pageno_correct, total_pages + globals.pageno_correct - 1);
+	sprintf(ofstring, "of %d to %d pages", globals.pageno_correct, total_pages + globals.pageno_correct - 1);
 
     if (act == FILE_PRINT && print_shell == NULL) {
 	curr_info->print_radio = resource.default_printing_target;
@@ -2523,14 +2523,14 @@ popdown_dialog_and_print_or_save(XtPointer myinfo)
 	break;
     }
 
-    store_user_preference("dvipsOptionsString", "%s", save_pr_info.dvips_options ? save_pr_info.dvips_options : "");
+    store_preference(NULL, "dvipsOptionsString", "%s", save_pr_info.dvips_options ? save_pr_info.dvips_options : "");
     if (pinfo->act == FILE_PRINT) {
-	store_user_preference("defaultPrintingTarget", "%d", save_pr_info.print_radio);
-	store_user_preference("dvipsPrinterString", "%s", save_pr_info.printer_name ? save_pr_info.printer_name : "");
+	store_preference(NULL, "defaultPrintingTarget", "%d", save_pr_info.print_radio);
+	store_preference(NULL, "dvipsPrinterString", "%s", save_pr_info.printer_name ? save_pr_info.printer_name : "");
 	internal_print(pinfo);
     }
     else {
-	store_user_preference("defaultSavingFormat", "%d", save_save_info.output_format);
+	store_preference(NULL, "defaultSavingFormat", "%d", save_save_info.output_format);
 	internal_save(pinfo, curr_info->output_format);
     }
 }
