@@ -194,7 +194,7 @@ cb_regexp_search(Widget w, XtPointer client_data, XtPointer call_data)
 	resource.search_window_defaults |= SETTINGS_USE_REGEXP_FLAG;
     else
 	resource.search_window_defaults &= ~SETTINGS_USE_REGEXP_FLAG;
-    store_user_preference("searchWindowDefaults", "%u", resource.search_window_defaults);
+    store_preference(NULL, "searchWindowDefaults", "%u", resource.search_window_defaults);
 }
 
 static void
@@ -217,7 +217,7 @@ cb_backwards_search(Widget w, XtPointer client_data, XtPointer call_data)
 	resource.search_window_defaults |= SETTINGS_BACKWARDS_FLAG;
     else
 	resource.search_window_defaults &= ~SETTINGS_BACKWARDS_FLAG;
-    store_user_preference("searchWindowDefaults", "%u", resource.search_window_defaults);
+    store_preference(NULL, "searchWindowDefaults", "%u", resource.search_window_defaults);
 }
 
 static void
@@ -236,7 +236,7 @@ cb_match_case(Widget w, XtPointer client_data, XtPointer call_data)
 	resource.search_window_defaults |= SETTINGS_CASE_SENSITIVE_FLAG;
     else
 	resource.search_window_defaults &= ~SETTINGS_CASE_SENSITIVE_FLAG;
-    store_user_preference("searchWindowDefaults", "%u", resource.search_window_defaults);
+    store_preference(NULL, "searchWindowDefaults", "%u", resource.search_window_defaults);
 }
 
 static void
@@ -256,7 +256,7 @@ cb_linebreaks(Widget w, XtPointer client_data, XtPointer call_data)
 	resource.search_window_defaults |= SETTINGS_IGNORE_LINEBREAKS_FLAG;
     else
 	resource.search_window_defaults &= ~SETTINGS_IGNORE_LINEBREAKS_FLAG;
-    store_user_preference("searchWindowDefaults", "%u", resource.search_window_defaults);
+    store_preference(NULL, "searchWindowDefaults", "%u", resource.search_window_defaults);
 }
 
 static void
@@ -278,7 +278,7 @@ cb_search_cancel(Widget w, XtPointer client_data, XtPointer call_data)
        will be eventually reset by do_pages() in events.c.
        (The scanning routines musn't reset it, since they
        might not be called again after this point!) */
-    globals.events.flags |= EV_FIND_CANCEL;
+    globals.ev.flags |= EV_FIND_CANCEL;
 
     search_signal_page_changed(); /* Hack to make search restart anew */
     search_erase_highlighting(True);
@@ -970,6 +970,10 @@ create_search_window(struct search_settings *settings)
     XtOverrideTranslations(find_button, xlats);
     XtOverrideTranslations(cancel_button, xlats);
     XtOverrideTranslations(searchbox_input, xlats);
+
+    /* following doesn't help to force input to textbox in xaw: */
+    /* XtInstallAllAccelerators(find_paned, find_paned); */
+    /* XtInstallAllAccelerators(searchbox_input, find_paned); */
     
     XtManageChild(form);
     XtManageChild(find_paned);
