@@ -387,7 +387,7 @@ filehist_select_cb(Widget w, XtPointer client_data, XtPointer call_data)
 	ptr++;
     TRACE_GUI((stderr, "User selected: %d, `%s'", idx, ptr));
     if (idx == 0) {
-	globals.events.flags |= EV_RELOAD;
+	globals.ev.flags |= EV_RELOAD;
 	return;
     }
     file_history_open(ptr);
