@@ -165,7 +165,7 @@ popdown_apply_cb(Widget widget, XtPointer client_data, XtPointer call_data)
 	XChangeGC(DISP, globals.gc.ruler, GCForeground, &values);
 
 	scanned_page = scanned_page_color = scanned_page_reset;
-	globals.events.flags |= EV_NEWPAGE;
+	globals.ev.flags |= EV_NEWPAGE;
 
     }
     else if (strcmp(cinfo->button_info->resource_name, "background") == 0) {
@@ -175,7 +175,7 @@ popdown_apply_cb(Widget widget, XtPointer client_data, XtPointer call_data)
 
 	resource.back_Pixel = cinfo->new_color.pixel;
 	scanned_page = scanned_page_color = scanned_page_reset;
-	globals.events.flags |= EV_RELOAD; /* EV_NEWPAGE not sufficient with color code ... */
+	globals.ev.flags |= EV_RELOAD; /* EV_NEWPAGE not sufficient with color code ... */
     }
     else if (strcmp(cinfo->button_info->resource_name, "highlight") == 0) {
 	XGCValues values;
@@ -187,7 +187,7 @@ popdown_apply_cb(Widget widget, XtPointer client_data, XtPointer call_data)
 	search_draw_inverted_regions();
 	resource.match_highlight_inverted = !resource.match_highlight_inverted;
 	/* end of hack to update match GC */
-	globals.events.flags |= EV_NEWPAGE; /* force redraw */
+	globals.ev.flags |= EV_NEWPAGE; /* force redraw */
     }
     
     XtUnmanageChild(widget);
