@@ -325,7 +325,7 @@ revert_resources(void)
 /*     if (need_redraw) */
     /* just reload it always, there's too many exceptions ...
        redraw isn't always sufficient if file has colors. */
-    globals.events.flags |= EV_RELOAD;
+    globals.ev.flags |= EV_RELOAD;
 
 }
 
