@@ -49,6 +49,8 @@
 #include "xdvi-config.h"
 #include "c-openmx.h"
 
+/* default toolbar pixmap file */
+#include "pixmaps/toolbar.xpm"
 
 #ifdef MOTIF
 #include <X11/Intrinsic.h>
@@ -312,7 +314,7 @@ create_pixmap(Widget parent, int iconidx, Pixmap *sen, Pixmap *insen)
     static Pixmap tools_mask;
     static Pixmap shade_map;
     static Pixmap shade_mask;
-
+    
     int		    status = 0;
     XpmAttributes   attr;
     Pixmap	    map;
@@ -322,8 +324,20 @@ create_pixmap(Widget parent, int iconidx, Pixmap *sen, Pixmap *insen)
     ASSERT(iconidx >= 0, "index must be positive");
     
     if (first_time) {
+	/* FIXME: We use a dummy window here to get the correct depth/visual for the
+	   pixmap creation (cant use globals.widgets.top_level since it's not realized
+	   yet and realizing it now would result in wrong dimensions) ... */
+	Widget dummy = XtVaAppCreateShell("xdvi", "Xdvi",
+					  transientShellWidgetClass, DISP,
+					  XtNdepth, G_depth,
+					  XtNvisual, G_visual,
+					  XtNcolormap, G_colormap,
+					  XtNmappedWhenManaged, False,
+					  NULL);
+	XtRealizeWidget(dummy); /* note: doesn't pop it up */
+	rootWindow = XtWindow(dummy);
 	screenNum = DefaultScreen(XtDisplay(globals.widgets.top_level));
-	rootWindow = RootWindow(XtDisplay(globals.widgets.top_level), screenNum);
+	ASSERT(rootWindow != 0, "");
 	XtVaGetValues(parent,
 		      XmNbackground, &color[BACKGROUND].pixel,
 		      XmNforeground, &color[FOREGROUND].pixel,
@@ -348,46 +362,34 @@ create_pixmap(Widget parent, int iconidx, Pixmap *sen, Pixmap *insen)
 						      kpse_program_text_format,
 						      0);
 	    TRACE_GUI((stderr,
-		       "pixmap file search via kpse_find_file: %s => %s\n",
+		       "pixmap file search via kpse_find_file: %s => %s",
 		       resource.toolbar_pixmap_file,
 		       pixmap_file_path ? (char*)pixmap_file_path : "<NULL>"));
-	    if (pixmap_file_path == NULL) { /* still no luck, complain */
-		popup_message(globals.widgets.top_level,
-			      MSG_ERR,
-			      /* helptext */
-			      "The pixmap file for the toolbar buttons has not been installed properly. "
-			      "To install it now, use one of the following methods:\n\n"
-			      "- Put the pixmap file into a directory /some/path/pixmaps/ "
-			      "(e.g., below your home directory), and add \"/some/path/%%T/%%N%%S\" "
-			      "to the XFILESEARCHPATH environment variable.\n\n"
-			      "- Put the file into $XDVIINPUTS (see the output of "
-			      "\"kpsewhich --expand-path='$XDVIINPUTS'\" for the value of $XDVIINPUTS).",
-			      /* msg */
-			      "Couldn't find toolbar pixmap file \"%s\" "
-			      "(the value of the resource \"toolbarPixmapFile\") "
-			      "in default search path. Disabling toolbar.",
-			      resource.toolbar_pixmap_file);
-		/* disable the toolbar */
-		resource.toolbar_unusable = True;
-		resource.expert_mode ^= XPRT_SHOW_TOOLBAR;
-		return False;
+	    if (pixmap_file_path == NULL) {
+		TRACE_GUI((stderr, "No installed toolbar pixmap found, using built-in pixmap."));
 	    }
 	}
     }
     
-    ASSERT(pixmap_file_path != NULL, "pixmap_file_path must have been initialized");
-    
     /* Setup the color subsititution table */
-    attr.valuemask = XpmColorSymbols | XpmCloseness;
+    attr.valuemask = XpmColorSymbols | XpmCloseness | XpmColormap | XpmDepth | XpmVisual;
     attr.closeness = 65535;	/* accuracy isn't crucial */
     attr.colorsymbols = color;
     attr.numsymbols = XtNumber(color);
-
+    attr.visual = G_visual;
+    attr.colormap = G_colormap;
+    attr.depth = G_depth;
+    
     /* Create the "sensitive" pixmap */
     if (!tools_map) {
-	status = XpmReadFileToPixmap(XtDisplay(globals.widgets.top_level), rootWindow,
-				     pixmap_file_path,
-				     &tools_map, &tools_mask, &attr);
+	if (pixmap_file_path != NULL) {
+	    status = XpmReadFileToPixmap(XtDisplay(globals.widgets.top_level), rootWindow,
+					 pixmap_file_path, &tools_map, &tools_mask, &attr);
+	}
+	else {
+	    status = XpmCreatePixmapFromData(XtDisplay(globals.widgets.top_level), rootWindow,
+					     (char **)toolbar_xpm, &tools_map, &tools_mask, &attr);
+	}
     }
     else
 	status = XpmSuccess;
@@ -423,8 +425,7 @@ create_pixmap(Widget parent, int iconidx, Pixmap *sen, Pixmap *insen)
     XpmFreeAttributes(&attr);
     
     if (map != 0) {
-	static GC    back_gc;
-	static GC    bots_gc;
+	static GC back_gc, bots_gc;
 
 	if (first_time) {
 	    XGCValues   gcvalues;
@@ -441,7 +442,7 @@ create_pixmap(Widget parent, int iconidx, Pixmap *sen, Pixmap *insen)
 
 	/* Create the "sensitive" pixmap. */
 	*sen = XCreatePixmap(XtDisplay(globals.widgets.top_level), rootWindow, PIXMAP_WIDTH, PIXMAP_HEIGHT,
-			     DefaultDepth(XtDisplay(globals.widgets.top_level), screenNum));
+			     G_depth);
 	XFillRectangle(XtDisplay(globals.widgets.top_level), *sen, back_gc, 0, 0, PIXMAP_WIDTH, PIXMAP_HEIGHT);
 	if (iconidx != -1)
 	    XCopyArea(XtDisplay(globals.widgets.top_level), map, *sen, bots_gc,
@@ -458,18 +459,26 @@ create_pixmap(Widget parent, int iconidx, Pixmap *sen, Pixmap *insen)
 	    Pixmap map;
 	    Pixmap mask;
 
-	    attr.valuemask = XpmColorSymbols | XpmCloseness | XpmColorKey;
+	    attr.valuemask = XpmColorSymbols | XpmCloseness | XpmColorKey | XpmColormap | XpmDepth | XpmVisual;
 	    attr.closeness = 65535;	/* accuracy isn't crucial */
 	    attr.colorsymbols = color;
 	    attr.numsymbols = XtNumber(color);
 	    attr.color_key = XPM_MONO;
+	    attr.visual = G_visual;
+	    attr.colormap = G_colormap;
+	    attr.depth = G_depth;
 
 
-
-	    if (!shade_map)
-		status = XpmReadFileToPixmap(XtDisplay(globals.widgets.top_level), rootWindow,
-					     pixmap_file_path,
-					     &shade_map, &shade_mask, &attr);
+	    if (!shade_map) {
+		if (pixmap_file_path != NULL) {
+		    status = XpmReadFileToPixmap(XtDisplay(globals.widgets.top_level), rootWindow,
+						 pixmap_file_path, &shade_map, &shade_mask, &attr);
+		}
+		else {
+		    status = XpmCreatePixmapFromData(XtDisplay(globals.widgets.top_level), rootWindow,
+						     (char **)toolbar_xpm, &shade_map, &shade_mask, &attr);
+		}
+	    }
 	    else
 		status = XpmSuccess;
 
@@ -521,7 +530,7 @@ create_pixmap(Widget parent, int iconidx, Pixmap *sen, Pixmap *insen)
 		XSetClipOrigin(XtDisplay(globals.widgets.top_level), tops_gc, 1, 1);
 
 		*insen = XCreatePixmap(XtDisplay(globals.widgets.top_level), rootWindow, PIXMAP_WIDTH, PIXMAP_HEIGHT,
-				       DefaultDepth(XtDisplay(globals.widgets.top_level), screenNum));
+				       G_depth);
 
 		XFillRectangle(XtDisplay(globals.widgets.top_level), *insen, back_gc, 0, 0,
 			       PIXMAP_WIDTH, PIXMAP_HEIGHT);
@@ -846,6 +855,6 @@ create_tips(Widget toplevel)
 
 
 #else /* MOTIF */
-/* silence `empty compilation unit' warnings */
-static void bar(void); static void foo() { bar(); } static void bar(void) { foo(); }
+/* silence "empty compilation unit" and "`toolbar_xpm' defined but not used" warnings */
+static void bar(void); static void foo() { UNUSED(toolbar_xpm); bar(); } static void bar(void) { foo(); }
 #endif /* MOTIF */
