@@ -172,33 +172,18 @@ fork_dvips(char **argv, const struct select_pages_info *pinfo, childProcT proc)
 	chdir(globals.dvi_file.dirname);
 
 	if (globals.debug & DBG_FILES) {
-	    char path[2 * PATH_MAX];
-	    getcwd(path, 2 * PATH_MAX);
+	    char path[MAXPATHLEN];
+	    getcwd(path, MAXPATHLEN);
 	    fprintf(stderr, "Directory of running `%s': `%s'\n",
 		    argv[0], path);
 	}
-	
-	if (finfo->dvi_tmp.fp != NULL) {
-	    /* printing from temporary instead of main file:
-	       make the temporary fp the STDIN of the dvips process */
+
+	/* make the input file pointer the STDIN of the dvips process */
+	if (finfo->dvi_tmp.fp != NULL) { /* printing selected pages from temporary file */
 	    (void)dup2(fileno(finfo->dvi_tmp.fp), STDIN_FILENO);
 	}
-	else {
-	    /* open dvi file anew so that seek()s on the
-	       original FILE * in the parent don't affect us */
-	    int fd;
-	    (void)close(STDIN_FILENO);
-	    (void)close(fileno(globals.dvi_file.bak_fp));
-	    if ((fd = try_open(globals.dvi_name, O_RDONLY)) < STDIN_FILENO) {
-		perror(globals.dvi_name);
-		fflush(stderr);
-		_exit(1);
-	    }
-	    /* make fd the stdin of child */
-	    if (fd > STDIN_FILENO) {
-		dup2(fd, STDIN_FILENO);
-		(void)close(fd);
-	    }
+	else { /* printing from main or backup file */
+	    (void)dup2(fileno(finfo->dvi_in.fp), STDIN_FILENO);
 	}
 	(void)lseek(0, 0, SEEK_SET);
 	
@@ -409,15 +394,12 @@ dvips_exited(int exitval, struct xchild *child)
 	    }
 	}
 	else
-	    sprintf(str, "\nPrint process returned exit code %d.\n",
-		    WEXITSTATUS(exitval));
+	    sprintf(str, "\nDvips returned exit code %d.\n", WEXITSTATUS(exitval));
     }
     else if (WIFSIGNALED(exitval))
-	sprintf(str, "\nPrint process terminated by signal %d.\n",
-		WTERMSIG(exitval));
+	sprintf(str, "\nDvips terminated by signal %d.\n", WTERMSIG(exitval));
     else
-	sprintf(str, "\nPrint process returned unknown status 0x%x.\n",
-		exitval);
+	sprintf(str, "\nDvips returned unknown status 0x%x.\n", exitval);
 
     ms = resource.dvips_hang;
     if (str[0] != '\0') {
@@ -608,8 +590,8 @@ cb_dvips_unkeep(Widget w, XtPointer client_data, XtPointer call_data)
     resource.dvips_hang = -resource.dvips_hang;
     resource.dvips_fail_hang = -resource.dvips_fail_hang;
 
-    store_user_preference("dvipsHangTime", "%d", resource.dvips_hang);
-    store_user_preference("dvipsFailHangTime", "%d", resource.dvips_fail_hang);
+    store_preference(NULL, "dvipsHangTime", "%d", resource.dvips_hang);
+    store_preference(NULL, "dvipsFailHangTime", "%d", resource.dvips_fail_hang);
 
     
     if (dvips_status == DVIPS_STAT_WAIT) {
