@@ -216,7 +216,7 @@ TextProc(DPSContext ctxt, char *buf, unsigned long count)
 	    if (p >= p0 + 8 && memcmp(p - 8, ackstr, 9) == 0) {
 		--DPS_pending;
 		if (DPS_pending == 0)
-		    globals.events.flags |= EV_ACK;
+		    globals.ev.flags |= EV_ACK;
 		if (globals.debug & DBG_PS)
 		    printf("Got DPS ack; %d pending.\n", DPS_pending);
 		++p;
@@ -231,7 +231,7 @@ TextProc(DPSContext ctxt, char *buf, unsigned long count)
 		++p;
 		(void)bcopy(p, p - 9, linepos - p);
 		linepos -= 9;
-		globals.events.flags |= EV_ACK;
+		globals.ev.flags |= EV_ACK;
 		continue;
 	    }
 	    if (p >= p0 + 8 && memcmp(p - 8, intstr2, 9) == 0) {
@@ -278,7 +278,7 @@ static void DPS_alarm(struct xtimer *arg)
 	puts("Received DPS alarm");
 
     DPS_timer_set = False;
-    globals.events.flags |= EV_ACK;
+    globals.ev.flags |= EV_ACK;
 }
 #endif /* SUNHACK */
 
@@ -290,13 +290,13 @@ waitack(void)
 
     DPSFlushContext(DPS_ctx);
     if (read_events(DPS_ev_mask | EV_ACK) & EV_ACK) {
-	globals.events.flags &= ~EV_ACK;
+	globals.ev.flags &= ~EV_ACK;
 	return;
     }
 
     if (globals.debug & DBG_PS)
 	printf("Interrupting DPS in waitack(); code is now %d %x\n",
-		XDPSGetContextStatus(DPS_ctx), globals.events.flags);
+		XDPSGetContextStatus(DPS_ctx), globals.ev.flags);
 
     DPS_active = DPS_in_header = DPS_in_doc = False;
     DPS_ev_mask = DPS_MASK_NORMAL;
@@ -317,7 +317,7 @@ waitack(void)
     DPSInterruptContext(DPS_ctx);
     DPSFlushContext(DPS_ctx);
     (void) read_events(EV_GE_TERM | EV_ACK);
-    globals.events.flags &= ~EV_ACK;
+    globals.ev.flags &= ~EV_ACK;
 
     XSync(DISP, False);
     DPSPrintf(DPS_ctx, " stop\n%%%%xdvimark\n stop\n%%%%xdvimark\n");
@@ -331,7 +331,7 @@ waitack(void)
     DPS_timer_set = True;
     set_timer(&DPS_timer, 500);
     (void) read_events(EV_GE_TERM | EV_ACK);
-    globals.events.flags &= ~EV_ACK;
+    globals.ev.flags &= ~EV_ACK;
 
     if (DPS_pending <= 0) {
 	if (DPS_timer_set) {
@@ -653,8 +653,8 @@ drawbeginDPS(int xul, int yul, const char *cp)
 	++DPS_pending;
     }
 
-    if (globals.events.flags & DPS_MASK_NORMAL)
-	longjmp(globals.events.canit, 1);
+    if (globals.ev.flags & DPS_MASK_NORMAL)
+	longjmp(globals.ev.canit, 1);
 
     DPSPrintf(DPS_ctx, "%d %d moveto\n", xul, yul);
     DPSPrintf(DPS_ctx, "%s\n", cp);
@@ -684,7 +684,7 @@ drawbeginDPS_box(int xul, int yul, const char *cp)
 static void
 drawrawDPS(const char *cp)
 {
-    if (!DPS_active || (globals.events.flags & DPS_ev_mask))
+    if (!DPS_active || (globals.ev.flags & DPS_ev_mask))
 	return;
 
     if (globals.debug & DBG_PS)
@@ -731,8 +731,8 @@ drawfileDPS(const char *cp, FILE *psfile)
 
     fclose(psfile);
 
-    if (globals.events.flags & DPS_ev_mask)
-	longjmp(globals.events.canit, 1);
+    if (globals.ev.flags & DPS_ev_mask)
+	longjmp(globals.ev.canit, 1);
 }
 
 
@@ -751,7 +751,7 @@ drawfileDPS(const char *cp, FILE *psfile)
 static void
 drawendDPS(const char *cp)
 {
-    if (!DPS_active || (globals.events.flags & DPS_MASK_NORMAL))
+    if (!DPS_active || (globals.ev.flags & DPS_MASK_NORMAL))
 	return;
 
     if (globals.debug & DBG_PS)
@@ -774,7 +774,7 @@ drawendDPS(const char *cp)
 static void
 beginheaderDPS(void)
 {
-    if (globals.events.flags & DPS_MASK_HEADER || !checkDPS())
+    if (globals.ev.flags & DPS_MASK_HEADER || !checkDPS())
 	return;
 
     if (globals.debug & DBG_PS)
