@@ -243,7 +243,7 @@ read_from_gs(int fd)
 	    if (memcmp(p, ackstr, 3) == 0) {
 		--GS_pending;
 		if (GS_pending == 0)
-		    globals.events.flags |= EV_ACK;
+		    globals.ev.flags |= EV_ACK;
 		if (globals.debug & DBG_PS)
 		    printf("Got GS ack; %d pending.\n", GS_pending);
 	    } else if (memcmp(p, oldstr, 3) == 0) {
@@ -324,7 +324,7 @@ write_to_gs(int fd)
 	    break;
 	}
     }
-    globals.events.flags |= GS_write_ack;
+    globals.ev.flags |= GS_write_ack;
     GS_write_ack = 0;
 }
 
@@ -341,7 +341,7 @@ gs_send(const char *cp, size_t len)
     char *old_out;
     Boolean interrupting;
 
-    if (GS_pid == 0 || (globals.events.flags & GS_ev_mask))
+    if (GS_pid == 0 || (globals.ev.flags & GS_ev_mask))
 	return;
 
     /*
@@ -395,7 +395,7 @@ gs_send(const char *cp, size_t len)
 	for (;;) {	/* loop because there may be stray ACKs */
 	    if (!interrupting) {
 		(void) read_events(GS_ev_mask | EV_ACK);
-		globals.events.flags &= ~EV_ACK;
+		globals.ev.flags &= ~EV_ACK;
 
 		if (GS_pid == 0) {	/* if GS died */
 		    GS_die_ack = 0;
@@ -405,7 +405,7 @@ gs_send(const char *cp, size_t len)
 		if (GS_outb_out != old_out)	/* if more room in buffer */
 		    break;
 
-		if (globals.events.flags & GS_ev_mask) {	/* if a serious event */
+		if (globals.ev.flags & GS_ev_mask) {	/* if a serious event */
 		    if (globals.debug & DBG_PS)
 			puts("Setting timeout in gs_send()");
 
@@ -415,7 +415,7 @@ gs_send(const char *cp, size_t len)
 	    }
 	    else {
 		(void) read_events(EV_GE_TERM | EV_PS_TOGGLE | EV_ACK);
-		globals.events.flags &= ~EV_ACK;
+		globals.ev.flags &= ~EV_ACK;
 
 		if (GS_outb_out != old_out)	/* if more room in buffer */
 		    break;
@@ -448,7 +448,7 @@ gs_alarm(struct xtimer *timer)
     if (globals.debug & DBG_PS)
 	puts("GS timeout expired");
 
-    globals.events.flags |= EV_ACK;
+    globals.ev.flags |= EV_ACK;
     GS_timer_set = False;
 #if TIMER_PROBLEM_FIXED
     gs_timeout_id = 0;
@@ -463,7 +463,7 @@ static	void
 waitack(void)
 {
     if (GS_pending == 0) {
-	globals.events.flags &= ~EV_ACK;
+	globals.ev.flags &= ~EV_ACK;
 	return;
     }
 
@@ -472,13 +472,13 @@ waitack(void)
     for (;;) {	/* loop because there might be stray ACKs. */
 /*  	fprintf(stderr, "looping for stray ACKs, page %d\n", current_page); */
 	(void) read_events(EV_GE_ACK);
-	globals.events.flags &= ~EV_ACK;
+	globals.ev.flags &= ~EV_ACK;
 
 	if (GS_pending == 0) {
 	    GS_die_ack = 0;
 	    return;
 	}
-	if (globals.events.flags & EV_GE_ACK)
+	if (globals.ev.flags & EV_GE_ACK)
 	    break;
     }
 
@@ -496,7 +496,7 @@ waitack(void)
     GS_timer_set = True;
 
     (void) read_events(EV_GE_TERM | EV_PS_TOGGLE | EV_ACK);
-    globals.events.flags &= ~EV_ACK;
+    globals.ev.flags &= ~EV_ACK;
 
     if (GS_timer_set) {
 #if TIMER_PROBLEM_FIXED
@@ -694,8 +694,8 @@ initGS(void)
 	toggle_gs(0);	/* if we got a 'v' already */
     else {
 	scanned_page = scanned_page_ps = scanned_page_reset;
-	globals.events.flags |= EV_NEWPAGE;	/* ||| redraw the page */
-	longjmp(globals.events.canit, 1);
+	globals.ev.flags |= EV_NEWPAGE;	/* ||| redraw the page */
+	longjmp(globals.ev.canit, 1);
     }
     return True;
 }
@@ -749,7 +749,7 @@ gs_died(int status, struct xchild *child)
     scanned_page = scanned_page_ps = scanned_page_reset;
     GS_active = GS_in_doc = False;
     GS_pending = 0;
-    globals.events.flags |= GS_die_ack;
+    globals.ev.flags |= GS_die_ack;
 }
 
 static	void
@@ -802,12 +802,12 @@ interrupt_gs(void)
       a file that should be reloaded.
     */
     if (GS_pending == 0) {
-/*  	fprintf(stderr, "+++++++++ 1st case; waitack: %d\n", globals.events.flags & EV_ACK); */
-	globals.events.flags &= ~EV_ACK;
+/*  	fprintf(stderr, "+++++++++ 1st case; waitack: %d\n", globals.ev.flags & EV_ACK); */
+	globals.ev.flags &= ~EV_ACK;
 	return;
     }
     else if (GS_pending < 0) {
-/*  	fprintf(stderr, "GS_pending: %d; waitack: %d\n", GS_pending, globals.events.flags & EV_ACK); */
+/*  	fprintf(stderr, "GS_pending: %d; waitack: %d\n", GS_pending, globals.ev.flags & EV_ACK); */
 	return;	/* nothing to do */
     }
 
@@ -853,8 +853,8 @@ checkgs(Boolean in_header)
     if (!GS_active) {
 	/* check whether page_w or page_h have increased */
 	if (globals.page.w > GS_page_w || globals.page.h > GS_page_h) {
-	    if (globals.events.flags & GS_ev_mask)
-		longjmp(globals.events.canit, 1);
+	    if (globals.ev.flags & GS_ev_mask)
+		longjmp(globals.ev.canit, 1);
 	    ++GS_pending;
 	    sprintf(buf,
 		    "H mark /HWSize [%d %d] /ImagingBBox [0 0 %d %d] "
@@ -867,14 +867,14 @@ checkgs(Boolean in_header)
 		    globals.page.w);
 	    gs_send(buf, strlen(buf));
 	    if (!in_header) {
-		globals.events.flags |= EV_NEWPAGE;	/* ||| redraw the page */
-		longjmp(globals.events.canit, 1);
+		globals.ev.flags |= EV_NEWPAGE;	/* ||| redraw the page */
+		longjmp(globals.ev.canit, 1);
 	    }
 	}
 
 	if (magnification != GS_mag) {
-	    if (globals.events.flags & GS_ev_mask)
-		longjmp(globals.events.canit, 1);
+	    if (globals.ev.flags & GS_ev_mask)
+		longjmp(globals.ev.canit, 1);
 	    ++GS_pending;
 	    sprintf(buf,
 		    "H TeXDict begin /DVImag %ld 1000 div def end stop\n"
@@ -884,8 +884,8 @@ checkgs(Boolean in_header)
 	}
 
 	if (mane.shrinkfactor != GS_shrink) {
-	    if (globals.events.flags & GS_ev_mask)
-		longjmp(globals.events.canit, 1);
+	    if (globals.ev.flags & GS_ev_mask)
+		longjmp(globals.ev.canit, 1);
 	    ++GS_pending;
 	    sprintf(buf,
 		    "H TeXDict begin %d %d div dup /Resolution X /VResolution X end stop\n"
@@ -906,8 +906,8 @@ drawbegin_gs(int xul, int yul, const char *cp)
     checkgs(False);
 
     if (!GS_active) {
-	if (globals.events.flags & GS_ev_mask)
-	    longjmp(globals.events.canit, 1);
+	if (globals.ev.flags & GS_ev_mask)
+	    longjmp(globals.ev.canit, 1);
 	++GS_pending;
 	gs_send(str, (sizeof str) - 1);
 	GS_active = True;
@@ -1023,9 +1023,9 @@ beginheader_gs(void)
 	return;
     }
 
-    if (globals.events.flags & GS_ev_mask) {
+    if (globals.ev.flags & GS_ev_mask) {
 /* 	fprintf(stderr, "longjmp!"); */
-	longjmp(globals.events.canit, 1);
+	longjmp(globals.ev.canit, 1);
     }
 
     GS_in_header = True;
