@@ -1097,7 +1097,7 @@ try_open_tempname(int status, struct xchild *this)
 		   So instead, we just close the file and force a redraw of the entire page.
 		*/
 		fclose(f);
-		globals.events.flags |= EV_NEWPAGE;
+		globals.ev.flags |= EV_NEWPAGE;
 	    }
 	}
     }
@@ -2205,8 +2205,8 @@ color_special(const char *cp)
 		scanned_page_ps = scanned_page;
 #endif
 /* 		fprintf(stderr, "forcing redraw!!!\n"); */
-		globals.events.flags |= EV_NEWPAGE;		/* force a redraw */
-		longjmp(globals.events.canit, 1);
+		globals.ev.flags |= EV_NEWPAGE;		/* force a redraw */
+		longjmp(globals.ev.canit, 1);
 	    }
 	    return;
 	}
@@ -2465,8 +2465,8 @@ applicationDoSpecial(char *cp, size_t len)
 # if COLOR
 	    scanned_page_color = scanned_page;
 # endif
-	    globals.events.flags |= EV_NEWPAGE;		/* force a redraw */
-	    longjmp(globals.events.canit, 1);
+	    globals.ev.flags |= EV_NEWPAGE;		/* force a redraw */
+	    longjmp(globals.ev.canit, 1);
 	}
 #endif /* PS */
 	return;
@@ -2481,8 +2481,8 @@ applicationDoSpecial(char *cp, size_t len)
 	    scanned_page_ps = scanned_page;
 # endif
 /* 	    fprintf(stderr, "forcing redraw!\n"); */
-	    globals.events.flags |= EV_NEWPAGE;		/* force a redraw */
-	    longjmp(globals.events.canit, 1);
+	    globals.ev.flags |= EV_NEWPAGE;		/* force a redraw */
+	    longjmp(globals.ev.canit, 1);
 	}
 #endif /* COLOR */
 	return;
@@ -2499,8 +2499,8 @@ applicationDoSpecial(char *cp, size_t len)
 #if COLOR
 	    scanned_page_color = scanned_page;
 #endif
-	    globals.events.flags |= EV_NEWPAGE; /* force a redraw */
-	    longjmp(globals.events.canit, 1);
+	    globals.ev.flags |= EV_NEWPAGE; /* force a redraw */
+	    longjmp(globals.ev.canit, 1);
 	}
 	return;
     }
