@@ -32,8 +32,6 @@
 #include "xdvi.h"
 #include "string-utils.h"
 #include "util.h"
-#include "my-vsnprintf.h"
-#include "my-snprintf.h"
 
 /*------------------------------------------------------------
  *  str_is_prefix
@@ -688,51 +686,15 @@ replace_extension(const char *fname, const char *extension,
 #define PTR_CONVERSION_LEN_GUESS sizeof(void *) * CHAR_BIT
 #endif
 
-/*
- * Allocate a string to contain argp. Uses VSNPRINTF in a way
- * that should work with all of glibc <= 2.0.6, >= 2.1, and the
- * implementation in my-vsnprintf.c.
- */
-char *
-get_string_argp(const char *fmt, va_list argp)
-{
-    char *buf = NULL;
-    int CHUNK_LEN = 128;
-    int curr_len = CHUNK_LEN, need_len;
-    
-    for (;;) {
-	/*
-	 * see man page for vsnprintf: for glibc 2.0, <need_len> is
-	 * -1 if <buf> had been trucated to <curr_len>; for glibc 2.1,
-	 * it's the total length of <fmt>; so the following works
-	 * with both versions:
-	 */
-	buf = xrealloc(buf, curr_len);
-	need_len = VSNPRINTF(buf, curr_len, fmt, argp);
-	if (need_len > -1 && need_len < curr_len) {	/* <curr_len> was large enough */
-	    break;
-	}
-	if (need_len > -1) {	/* now need_len + 1 is the exact space needed */
-	    curr_len = need_len + 1;
-	}
-	else {	/* try again with larger <len> */
-	    curr_len += CHUNK_LEN;
-	}
-    }
-    return buf;
-}
-    
+   
 /*
  * Return a formatted string in newly allocated memory.
  */
 char *
 get_string_va(const char *fmt, ...)
 {
-    char *buf;
-    va_list argp;
-    va_start(argp, fmt);
-    buf = get_string_argp(fmt, argp);
-    va_end(argp);
+    char *buf = NULL;
+    XDVI_GET_STRING_ARGP(buf, fmt);
     return buf;
 }
 
