@@ -223,8 +223,8 @@ static const char default_menu_config[] =
     "Options|O > Use TeX Page Numbers|T	:CHECK	:T	:use-tex-pages(toggle)\n"
     "Options|O				:SEP	::\n"
 /* removed this one, since it only duplicates the toolbar and is too awkward to use */
-/*     "Options|O > Fonts|F > Fonts Darker|D		:PUSH	:Alt-Ctrl-+	:change-density(25)\n" */
-/*     "Options|O > Fonts|F > Fonts Lighter|L		:PUSH	:Alt-Ctrl--	:change-density(-25)\n" */
+/*     "Options|O > Fonts|F > Fonts Darker|D		:PUSH	:Alt-Ctrl-+	:change-density(5)\n" */
+/*     "Options|O > Fonts|F > Fonts Lighter|L		:PUSH	:Alt-Ctrl--	:change-density(-5)\n" */
 /* ---------- */
 #if 0
 /* TODO: implement setting paper size at runtime */
@@ -349,8 +349,8 @@ static const char default_menu_config[] =
 /*     "Options:SEP\n" */
 /*     "Options:Show statusline:1 x:set-expert-mode(1)\n" */
     "Options:	SEP\n"
-    "Options:	Fonts Darker:		Alt-Ctrl-+:	change-density(25)\n"
-    "Options:	Fonts Lighter:		Alt-Ctrl--:	change-density(-25)\n"
+    "Options:	Fonts Darker:		Alt-Ctrl-+:	change-density(5)\n"
+    "Options:	Fonts Lighter:		Alt-Ctrl--:	change-density(-5)\n"
     "Help:	Introduction ...:	:		help(Introduction)\n"
     "Help:	Page Motion ...:	:		help(Page Motion)\n"
     "Help:	Other Commands ...:	:		help(Other Commands)\n"
@@ -369,14 +369,14 @@ static const char default_menu_config[] =
 static const char default_toolbar_translations[] =
 /*  index	statusline-text					tooltip		action */
     "SPACER(5)\n"
-    "0:	Open a new document   (Key\\: Ctrl-o):			Open file:	select-dvi-file()\n"
+    "0:	Open a new file   (Key\\: Ctrl-o):			Open file:	select-dvi-file()\n"
     "SPACER(10)\n"
-    "1:	Reread this document   (Key\\: R):			Reread file:	reread-dvi-file()\n"
+    "1:	Reload this file   (Key\\: R):				Reload file:	reread-dvi-file()\n"
     "SPACER(10)\n"
-    "2:	Go to the first page of this document   (Key\\: 1g):	First page:	goto-page(1)\n"
-    "3:	Go to the previous page of this document   (Key\\: p):	Previous page:	back-page(1)\n"
-    "4:	Go to the next page of this document   (Key\\: n):	Next page:	forward-page(1)\n"
-    "5:	Go to the last page of this document   (Key\\: g):	Last page:	goto-page(e)\n"
+    "2:	Go to the first page of this file   (Key\\: 1g):	First page:	goto-page(1)\n"
+    "3:	Go to the previous page of this file   (Key\\: p):	Previous page:	back-page(1)\n"
+    "4:	Go to the next page of this file   (Key\\: n):	Next page:	forward-page(1)\n"
+    "5:	Go to the last page of this file   (Key\\: g):	Last page:	goto-page(e)\n"
     "SPACER(10)\n"
     "8:	Back to previous page in history   (Key\\: [):	Page History back:	pagehistory-back()\n"
     "9:	Forward to next page in history   (Key\\: ]):	Page History forward:	pagehistory-forward()\n"
@@ -384,7 +384,7 @@ static const char default_toolbar_translations[] =
     "6:	Zoom in   (Key\\: Ctrl-+):		Zoom in:		set-shrink-factor(+)\n"
     "7:	Zoom out   (Key\\: Ctrl--):		Zoom out:		set-shrink-factor(-)\n"
     "SPACER(10)\n"
-    "11:Print this document:Print:print()\n"
+    "11:Print this DVI file:Print:print()\n"
     "SPACER(10)\n"
     "16:Find in DVI file   (Key\\: Ctrl-f):	Find in file:	find()\n"
     "SPACER(10)\n"
