@@ -397,7 +397,7 @@ xdvi_exit(int status)
 	char *filehist;
 	file_history_set_page(current_page);
 	filehist = file_history_get_list();
-	store_user_preference("fileHistory", "%s", filehist);
+	store_preference(NULL, "fileHistory", "%s", filehist);
 	free(filehist);
 
 #if MOTIF
@@ -553,7 +553,7 @@ expand_homedir(const char *path)
   overflows (e.g. this version is not affected by
   http://isec.pl/vulnerabilities/isec-0011-wu-ftpd.txt).
   
-  `resolved' should be a buffer of size PATH_MAX.  */
+  `resolved' should be a buffer of size MAXPATHLEN.  */
 
 char *
 my_realpath(const char *path, char *resolved)
@@ -792,6 +792,7 @@ alloc_bitmap(struct bitmap *bitmap)
 {
     unsigned int size;
 
+    /* fprintf(stderr, "allocating bitmap of size %u x %u\n", bitmap->w, bitmap->h); */
     /* width must be multiple of <arch-defined> bits for raster_op */
     bitmap->bytes_wide = ROUNDUP((int)bitmap->w, BMBITS) * BMBYTES;
     size = bitmap->bytes_wide * bitmap->h;
@@ -1138,8 +1139,8 @@ fork_process(const char *proc_name, Boolean redirect_stdout,
 	if (dirname != NULL)
 	    chdir(dirname);
 	if (globals.debug & DBG_FILES) {
-	    char path[2 * PATH_MAX];
-	    getcwd(path, 2 * PATH_MAX);
+	    char path[MAXPATHLEN];
+	    getcwd(path, MAXPATHLEN);
 	    fprintf(stderr, "Directory of running `%s': `%s'\n",
 		    proc_name, path);
 	}
@@ -1603,9 +1604,9 @@ put_str_int_hash(hashTableT *hashtable, const char *key, size_t val)
     hash_insert(hashtable, key, (const string)ptr);
 }
 
-/* set dvi_name, globals.dvi_file.dirname and globals.dvi_file.dirlen */
+/* set globals.dvi_name, globals.dvi_file.dirname and globals.dvi_file.dirlen */
 void
-set_dvi_name(const char *new_filename)
+set_dvi_name_expand(const char *new_filename)
 {
     ASSERT(new_filename != NULL, "");
     free(globals.dvi_name);
@@ -1618,6 +1619,23 @@ set_dvi_name(const char *new_filename)
     globals.dvi_file.dirlen = strlen(globals.dvi_file.dirname);
 }   
 
+/* set globals.dvi_name, globals.dvi_file.dirname and globals.dvi_file.dirlen
+   In contrast to previous function, input filename is not copied.
+ */
+void
+set_dvi_name(char *new_filename)
+{
+    ASSERT(new_filename != NULL, "");
+    free(globals.dvi_name);
+    globals.dvi_name = new_filename;
+
+    free(globals.dvi_file.dirname);
+    globals.dvi_file.dirname = get_dir_component(globals.dvi_name);
+
+    ASSERT(globals.dvi_file.dirname != NULL, "dvi_name should be a path with dir component");
+    globals.dvi_file.dirlen = strlen(globals.dvi_file.dirname);
+}   
+
 /*
  * Copy the file pointer `in' to the file pointer `out'.  Return True
  * if successful, False else (in which case caller should examine
