@@ -786,21 +786,26 @@ unexpected_widget_in_callback(Widget w, const char *callback)
 		  XtName(w), callback);
 }
 
+static XrmDatabase m_user_db = NULL;
+
 /*
  * Merge the resource `name' with a value specified by `fmt' into
- * the current display database.
+ * the database `db' (if db == NULL, use m_user_db).
  */
-static void
-internal_store_pref(XrmDatabase *db, const char *name, const char *fmt, va_list argp)
+void
+store_preference(XrmDatabase *db, const char *name, const char *fmt, ...)
 {
-    char *buf = get_string_argp(fmt, argp);
     size_t offset = strlen("xdvi.");
     size_t name_len = strlen(name);
     char *name_buf = xmalloc(name_len + offset + 1);
+    char *buf = NULL;
     XrmDatabase tmp_db = NULL;
-
-    buf = get_string_argp(fmt, argp);
     
+    if (db == NULL)
+	db = &m_user_db;
+
+    XDVI_GET_STRING_ARGP(buf, fmt);
+
     memcpy(name_buf, "xdvi.", offset);
     strcpy(name_buf + offset, name);
 
@@ -812,27 +817,6 @@ internal_store_pref(XrmDatabase *db, const char *name, const char *fmt, va_list
     free(name_buf);
 }
 
-void
-store_preference(XrmDatabase *db, const char *name, const char *fmt, ...)
-{
-    va_list argp;
-    
-    va_start(argp, fmt);
-    internal_store_pref(db, name, fmt, argp);
-    va_end(argp);
-}
-
-static XrmDatabase m_user_db = NULL;
-void
-store_user_preference(const char *name, const char *fmt, ...)
-{
-    va_list argp;
-
-    va_start(argp, fmt);
-    internal_store_pref(&m_user_db, name, fmt, argp);
-    va_end(argp);
-}
-
 void
 merge_into_user_db(XrmDatabase db)
 {
@@ -891,7 +875,7 @@ save_geometry(void)
 		  NULL);
     TRACE_GUI((stderr, "geometry: %dx%d+%d+%d", w, h, x_off, y_off));
 
-    store_user_preference("windowSize", "%dx%d", w, h);
+    store_preference(NULL, "windowSize", "%dx%d", w, h);
 }
 
 /* Save user preferences to ~/.xdvirc. If `backup_only' is True,
