@@ -141,6 +141,7 @@ in xdvi.c.
 #ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h> /* this should define MAXPATHLEN */
 #endif
+#include "kpathsea/c-pathmx.h" /* get fallback for PATH_MAX if all else fails */
 
 #include <X11/Xlib.h>	/* include Xfuncs.h, if available */
 #include <X11/Xutil.h>	/* needed for XDestroyImage */
@@ -730,7 +731,7 @@ extern struct program_globals {
     struct src_info src;
     
     /* event information */
-    struct event_info events;
+    struct event_info ev;
 
     /* support for `-pause' feature */
     struct pause_info pausing;
